MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / dnmat_divide_kernel

Function dnmat_divide_kernel

XM/include/Dense/matdivide.h:9–19  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

7
8template <typename T>
9__global__ void dnmat_divide_kernel(
10 T* dnmat3_vals, T* dnmat1_vals, T* dnmat2_vals,
11 size_s total_len, const size_s power
12) {
13 size_l idx = threadIdx.x + blockIdx.x * blockDim.x;
14 if (idx < total_len) {
15 if(power == 1) dnmat3_vals[idx] = dnmat1_vals[idx] / dnmat2_vals[idx];
16 else dnmat3_vals[idx] = dnmat1_vals[idx] / pow(dnmat2_vals[idx],power);
17 }
18 return;
19}
20
21// cpu function of Ddot
22template <typename T>

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected